@@ -14,6 +14,6 @@ reference_peaks_detector <- function(input_path_pl, file_names_ref, min_frequenc
   x_unique <- which(table(round_mz) == 1)
   unique_mz <- as.numeric(names(x_unique))
   select_mz <- round_mz%in%unique_mz
-  reference_mz_rt_peaks <- mz_rt_Xmed_ref[select_mz, ]
+  reference_mz_rt_peaks <- matrix(mz_rt_Xmed_ref[select_mz, ], ncol = 2)
   return(reference_mz_rt_peaks)
 }
