@@ -1,10 +1,10 @@
 xlsxAnalyzer_EIC <- function (spreadsheet) {
   ##
-  checkpoint_parameter <- 0
+  checkpoint_parameter <- FALSE
   if (length(spreadsheet) >= 4) {
     if (typeof(spreadsheet) == "list") {
       PARAM <- cbind(spreadsheet[, 2], spreadsheet[, 4])
-      checkpoint_parameter <- 1
+      checkpoint_parameter <- TRUE
     } else {
       print("The IPA input was not produced properly!")
     }
@@ -13,7 +13,7 @@ xlsxAnalyzer_EIC <- function (spreadsheet) {
       if (file.exists(spreadsheet)){
         spreadsheet_IPA <- readxl::read_xlsx(spreadsheet, sheet = 'IPA_targeted')
         PARAM <- cbind(spreadsheet_IPA[, 2], spreadsheet_IPA[, 4])
-        checkpoint_parameter <- 1
+        checkpoint_parameter <- TRUE
       } else {
         print("The IPA spreadsheet not found! It should be an Excel file with .xlsx extention!")
       }
@@ -23,41 +23,41 @@ xlsxAnalyzer_EIC <- function (spreadsheet) {
   } else {
     print("The IPA spreadsheet was not produced properly!")
   }
-  if (checkpoint_parameter == 1) {
+  if (checkpoint_parameter == TRUE) {
     ############################################################################
     x0006 <- as.numeric(PARAM[which(PARAM[, 1] == 'PARAM0006'), 2])
     if (is.na(x0006)) {
       print("ERROR!!! Problem with PARAM0006!")
-      checkpoint_parameter <- 0
+      checkpoint_parameter <- FALSE
     } else {
       if (x0006 >= 1) {
         if ((x0006 %% 1) != 0) {
           print("ERROR!!! Problem with PARAM0006! This parameter should be a positive integer!")
-          checkpoint_parameter <- 0
+          checkpoint_parameter <- FALSE
         }
       } else {
         print("ERROR!!! Problem with PARAM0006! This parameter should be at least 1 !")
-        checkpoint_parameter <- 0
+        checkpoint_parameter <- FALSE
       }
     }
     ##
     x0007 <- which(PARAM[, 1] == 'PARAM0007')
     if (length(x0007) == 0) {
       print("ERROR!!! Problem with PARAM0007!")
-      checkpoint_parameter <- 0
+      checkpoint_parameter <- FALSE
     } else {
       address_hrms <- PARAM[x0007, 2]
       address_hrms <- gsub("\\", "/", address_hrms, fixed=TRUE)
       PARAM[x0007, 2] <- address_hrms
       if (!dir.exists(address_hrms)) {
         print("ERROR!!! Problem with PARAM0007! Please make sure the full path is provided!")
-        checkpoint_parameter <- 0
+        checkpoint_parameter <- FALSE
       }
       ##
       x0008 <- which(PARAM[, 1] == 'PARAM0008')
       if (is.na(PARAM[x0008, 2])) {
         print("ERROR!!! Problem with PARAM0008!")
-        checkpoint_parameter <- 0
+        checkpoint_parameter <- FALSE
       } else {
         if (tolower(PARAM[x0008, 2]) != "all") {
           samples_string <- PARAM[x0008, 2]
@@ -72,7 +72,7 @@ xlsxAnalyzer_EIC <- function (spreadsheet) {
             for (i in 1:length(x_ID)) {
               print(name[x_ID[i]])
             }
-            checkpoint_parameter <- 0
+            checkpoint_parameter <- FALSE
           }
         }
         ##
@@ -80,13 +80,13 @@ xlsxAnalyzer_EIC <- function (spreadsheet) {
           x0009 <- PARAM[which(PARAM[, 1] == 'PARAM0009'), 2]
           if (is.na(x0009)) {
             print("ERROR!!! Problem with PARAM0009!")
-            checkpoint_parameter <- 0
+            checkpoint_parameter <- FALSE
           } else {
             if (tolower(x0009) == "mzml" | tolower(x0009) == "mzxml") {
               cat("")
             } else {
               print("ERROR!!! Problem with PARAM0009! HRMS data are incompatible!")
-              checkpoint_parameter <- 0
+              checkpoint_parameter <- FALSE
             }
           }
         }
@@ -96,15 +96,15 @@ xlsxAnalyzer_EIC <- function (spreadsheet) {
     x0010 <- which(PARAM[, 1] == 'PARAM0010')
     if (length(x0010) == 0) {
       print("ERROR!!! Problem with PARAM0010!")
-      checkpoint_parameter <- 0
+      checkpoint_parameter <- FALSE
     } else {
-      output_path <- gsub("\\", "/", PARAM[x0010, 2], fixed=TRUE)
+      output_path <- gsub("\\", "/", PARAM[x0010, 2], fixed = TRUE)
       PARAM[x0010, 2] <- output_path
       if (!dir.exists(output_path)) {
         tryCatch(dir.create(output_path))
         if (!dir.exists(output_path)) {
           print("ERROR!!! Problem with PARAM0010! R can only create one folder!")
-          checkpoint_parameter <- 0
+          checkpoint_parameter <- FALSE
         }
       }
     }
@@ -112,72 +112,72 @@ xlsxAnalyzer_EIC <- function (spreadsheet) {
     x0012 <- as.numeric(PARAM[which(PARAM[, 1] == 'PARAM0012'), 2])
     if (is.na(x0012)) {
       print("ERROR!!! Problem with PARAM0012! This parameter should be a positive number!")
-      checkpoint_parameter <- 0
+      checkpoint_parameter <- FALSE
     } else {
       if (x0012 <= 0) {
         print("ERROR!!! Problem with PARAM0012! This parameter should be a positive number!")
-        checkpoint_parameter <- 0
+        checkpoint_parameter <- FALSE
       }
     }
     #################### Chromatographic peak detection ######################
     x0013 <- as.numeric(PARAM[which(PARAM[, 1] == 'PARAM0013'), 2])
     if (is.na(x0013)) {
       print("ERROR!!! Problem with PARAM0013!")
-      checkpoint_parameter <- 0
+      checkpoint_parameter <- FALSE
     } else {
       if (x0013 <= 0) {
         print("ERROR!!! Problem with PARAM0013! This value should be a positive number!")
-        checkpoint_parameter <- 0
+        checkpoint_parameter <- FALSE
       }
     }
     ##
     x0015 <- as.numeric(PARAM[which(PARAM[, 1] == 'PARAM0015'), 2])
     if (is.na(x0015)) {
       print("ERROR!!! Problem with PARAM0015! This parameter should be a positive number!")
-      checkpoint_parameter <- 0
+      checkpoint_parameter <- FALSE
     } else {
       if (x0015 > 0) {
         cat("\n")
       } else {
         print("ERROR!!! Problem with PARAM0015! This parameter should be a positive number!")
-        checkpoint_parameter <- 0
+        checkpoint_parameter <- FALSE
       }
     }
     ##
     # x0016 <- as.numeric(PARAM[which(PARAM[, 1] == 'PARAM0016'), 2])
     # if (is.na(x0016)) {
     #   print("ERROR!!! Problem with PARAM0016! This parameter should be a positive integer!")
-    #   checkpoint_parameter <- 0
+    #   checkpoint_parameter <- FALSE
     # } else {
     #   if (x0016 <= 0) {
     #     print("ERROR!!! Problem with PARAM0016! This parameter should be a positive integer!")
-    #     checkpoint_parameter <- 0
+    #     checkpoint_parameter <- FALSE
     #   }
     # }
     ##
     x0017 <- as.numeric(PARAM[which(PARAM[, 1] == 'PARAM0017'), 2])
     if (is.na(x0017)) {
       print("ERROR!!! Problem with PARAM0017! This value should be a positive number between 0-0.05 !")
-      checkpoint_parameter <- 0
+      checkpoint_parameter <- FALSE
     } else {
       if (x0017 < 0 | x0017 > 0.1) {
         print("ERROR!!! Problem with PARAM0017! This value should be a positive number between 0-0.05 !")
-        checkpoint_parameter <- 0
+        checkpoint_parameter <- FALSE
       }
     }
     ##
     x0020 <- as.numeric(PARAM[which(PARAM[, 1] == 'PARAM0020'), 2])
     if (is.na(x0020)) {
       print("ERROR!!! Problem with PARAM0020! This parameter should be a positive integer!")
-      checkpoint_parameter <- 0
+      checkpoint_parameter <- FALSE
     } else {
       if (x0020 <= 0) {
         print("ERROR!!! Problem with PARAM0020! This parameter should be a positive integer!")
-        checkpoint_parameter <- 0
+        checkpoint_parameter <- FALSE
       } else {
         if ((x0020 %% 1) != 0) {
           print("ERROR!!! Problem with PARAM0020! This parameter should be a positive integer!")
-          checkpoint_parameter <- 0
+          checkpoint_parameter <- FALSE
         }
       }
     }
@@ -185,18 +185,18 @@ xlsxAnalyzer_EIC <- function (spreadsheet) {
     x0028 <- as.numeric(PARAM[which(PARAM[, 1] == 'PARAM0028'), 2])
     if (is.na(x0028)) {
       print("ERROR!!! Problem with PARAM0028! This parameter should be a positive integer greater than or equal to 11 !")
-      checkpoint_parameter <- 0
+      checkpoint_parameter <- FALSE
     } else {
       if (x0028 < 0) {
         print("ERROR!!! Problem with PARAM0028! This parameter should be a positive integer greater than or equal to 11 !")
-        checkpoint_parameter <- 0
+        checkpoint_parameter <- FALSE
       } else if (x0028 <= 11 && x0028 >= 1) {
         print("ERROR!!! Problem with PARAM0028! This parameter should be a positive integer greater than or equal to 11 !")
-        checkpoint_parameter <- 0
+        checkpoint_parameter <- FALSE
       } else {
         if ((x0028 %% 1) != 0) {
           print("ERROR!!! Problem with PARAM0028! This parameter should be a positive integer greater than or equal to 11 !")
-          checkpoint_parameter <- 0
+          checkpoint_parameter <- FALSE
         }
       }
     }
@@ -204,7 +204,7 @@ xlsxAnalyzer_EIC <- function (spreadsheet) {
     mzCandidate <- eval(parse(text = paste0("c(", PARAM[which(PARAM[, 1] == 'PARAM_MZ'), 2], ")")))
     rtCandidate <- eval(parse(text = paste0("c(", PARAM[which(PARAM[, 1] == 'PARAM_RT'), 2], ")")))
     if (length(mzCandidate) !=  length(rtCandidate)) {
-      checkpoint_parameter <- 0
+      checkpoint_parameter <- FALSE
       print("Error!!! Problems with PARAM_MZ and PARAM_RT ! mz and RT vectors do not have the same length!")
     }
     ##
@@ -212,7 +212,7 @@ xlsxAnalyzer_EIC <- function (spreadsheet) {
     if (ipa_eic_tar == "y" | ipa_eic_tar == "yes" | ipa_eic_tar == "n" | ipa_eic_tar == "no") {
       cat("\n")
     } else {
-      checkpoint_parameter <- 0
+      checkpoint_parameter <- FALSE
       print("Error!!! Problems with PARAM_EIC !")
     }
     ##
@@ -220,13 +220,13 @@ xlsxAnalyzer_EIC <- function (spreadsheet) {
     if (ipa_tab_tar == "y" | ipa_tab_tar == "yes" | ipa_tab_tar == "n" | ipa_tab_tar == "no") {
       cat("\n")
     } else {
-      checkpoint_parameter <- 0
+      checkpoint_parameter <- FALSE
       print("Error!!! Problems with PARAM_EIC !")
     }
     ##
   }
   ##############################################################################
-  if (checkpoint_parameter == 0) {
+  if (checkpoint_parameter == FALSE) {
     print("Please visit   https://ipa.idsl.me    for instructions!")
     PARAM <- c()
   }
